DataField class
Per-field configuration on a @dataBuilder class.
- key: map key override (defaults to the field name).
- includeIfNull: when false, the entry is omitted from
build()if null. - settable: when false, no
withXis generated and the field always serializes its default.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeIfNull → bool
-
final
- key → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settable → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited