DataPreset class
Marks a zero-argument schema method as a named builder preset.
The method name becomes a generated fluent method prefixed with with and
each assignment in its body is applied atomically to the immutable builder.
For example:
@DataPreset()
void pending() {
key = 'PendingEntry';
label = 'Required';
}
generates withPending() on the corresponding builder.
Constructors
- DataPreset()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited